WASM DBMS API
Runtime-agnostic API types and traits for the wasm-dbms engine.
This crate provides all shared types, traits, and abstractions needed to interact with a wasm-dbms instance. It is independent of any specific WASM runtime (IC, WASI, Wasmtime, etc.).
Import all useful types and traits via the prelude:
Feature flags
candid: EnablesCandidTypederives on all public types and exposes Candid-specific API boundary types (CandidColumnDef,CandidDataTypeKind).