Module dbms

Module dbms 

This module contains the main DBMS abstractions and functionalities.

Modules

custom_value
database
foreign_fetcher
query
This module exposes all the types related to queries that can be performed on the DBMS.
sanitize
This module contains all the built-in sanitizers which can be applied to columns.
table
This module contains types related to database tables.
transaction
types
This module exposes the data types used in the DBMS.
validate
This module contains all the built-in validations which can be applied to columns.
value