Module query

Module query 

This module exposes all the types related to queries that can be performed on the DBMS.

Structs

Join
A JOIN clause specifying which table to join and on which columns.
Query
A struct representing a query in the DBMS.
QueryBuilder
A builder for constructing database Queryes.

Enums

DeleteBehavior
Defines the behavior for delete operations regarding foreign key constraints.
Filter
super::Query filters.
JoinType
Specifies the JOIN operation type.
JsonCmp
Represents comparison operations for JSON values.
JsonFilter
JSON-specific filter operations.
OrderDirection
An enum representing the direction of ordering in a query.
QueryError
An enum representing possible errors that can occur during query operations.
Select
An enum representing the fields to select in a query.

Type Aliases

QueryResult
The result type for query operations.