QueryBuilder

Struct QueryBuilder 

pub struct QueryBuilder { /* private fields */ }
A builder for constructing database Queryes.

Implementations

Source

impl QueryBuilder

pub fn build(self) -> Query

Builds and returns a Query object based on the current state of the QueryBuilder.

pub fn field(self, field: &str) -> Self

Adds a field to select in the query.

pub fn fields<I>(self, fields: I) -> Self
where I: IntoIterator<Item = &'static str>,

Adds multiple fields to select in the query.

pub fn all(self) -> Self

Sets the query to select all fields.

pub fn with(self, table_relation: &str) -> Self

Adds a relation to eagerly load with the main records.

pub fn inner_join(self, table: &str, left_col: &str, right_col: &str) -> Self

Adds an INNER JOIN operation to this query

pub fn left_join(self, table: &str, left_col: &str, right_col: &str) -> Self

Adds a LEFT JOIN operation to this query

pub fn right_join(self, table: &str, left_col: &str, right_col: &str) -> Self

Adds a RIGHT JOIN operation to this query

pub fn full_join(self, table: &str, left_col: &str, right_col: &str) -> Self

Adds a FULL JOIN operation to this query

pub fn order_by_asc(self, field: &str) -> Self

Adds an ascending order by clause for the specified field.

pub fn order_by_desc(self, field: &str) -> Self

Adds a descending order by clause for the specified field.

pub fn limit(self, limit: usize) -> Self

Sets a limit on the number of records to return.

pub fn offset(self, offset: usize) -> Self

Sets an offset for pagination.

pub fn filter(self, filter: Option<Filter>) -> Self

Sets a filter for the query, replacing any existing filter.

pub fn and_where(self, filter: Filter) -> Self

Adds a filter to the query, combining with existing filters using AND.

pub fn or_where(self, filter: Filter) -> Self

Adds a filter to the query, combining with existing filters using OR.