IndexDef

Struct IndexDef 

pub struct IndexDef(pub &'static [&'static str]);
Defines an index on one or more columns of a table.

Contains a static slice of column names that make up the index, in the order they are defined.

Tuple Fields

0: &'static [&'static str]

Implementations

Source

impl IndexDef

pub fn columns(&self) -> &'static [&'static str]

Returns the column names that make up this index.