Module types

Module types 

This module exposes the data types used in the DBMS.

Structs

Blob
Blob data type for the DBMS.
Boolean
Boolean data type for the DBMS.
Date
Date data type for the DBMS.
DateTime
Date time data type for the DBMS.
Decimal
Decimal data type for the DBMS.
Int8
An integer type wrapper around a primitive integer type.
Int16
An integer type wrapper around a primitive integer type.
Int32
An integer type wrapper around a primitive integer type.
Int64
An integer type wrapper around a primitive integer type.
Json
Json data type for the DBMS.
Text
Text data type for the DBMS.
Uint8
An integer type wrapper around a primitive integer type.
Uint16
An integer type wrapper around a primitive integer type.
Uint32
An integer type wrapper around a primitive integer type.
Uint64
An integer type wrapper around a primitive integer type.
Uuid
UUID data type for the DBMS.

Enums

DataTypeKind
An enumeration of all supported data type kinds in the DBMS.
Nullable
Nullable data type for the DBMS.

Traits

CustomDataType
A trait for user-defined custom data types.
DataType
A trait representing a data type that can be stored in the DBMS.