This module contains all the built-in validations which can be applied to columns.
Each validation function takes a [&crate::prelude::Value] as input and returns a DbmsResult<()> indicating
whether the value passes the validation or not.
Structs
- Camel
Case Validator - A validator for
CamelCasestrings. - Country
Iso639 Validator - Validator for ISO639 country codes.
- Country
Iso3166 Validator - Validator for ISO3166 country codes.
- Email
Validator - A validator for email addresses.
- Kebab
Case Validator - A validator for
kebab-casestrings. - MaxStrlen
Validator - A validator that checks if the length of a string does not exceed a maximum length.
- Mime
Type Validator - A validator that checks if a string is a valid MIME type.
- MinStrlen
Validator - A validator that checks if the length of a string is at least a minimum length.
- Phone
Number Validator - A validator for phone numbers.
- Range
Strlen Validator - A validator that checks if the length of a string is within a specified range.
- RgbColor
Validator - A validator for RGB color strings.
- Snake
Case Validator - A validator for
snake_casestrings. - UrlValidator
- A validator that checks if a string is a valid URL.
Traits
- Validate
- Trait for validating
crate::prelude::Values.