Enum Value Copy item path Source pub enum Value {
Show 18 variants Blob(Blob ),
Boolean(Boolean ),
Date(Date ),
DateTime(DateTime ),
Decimal(Decimal ),
Int8(Int8 ),
Int16(Int16 ),
Int32(Int32 ),
Int64(Int64 ),
Json(Json ),
Null,
Text(Text ),
Uint8(Uint8 ),
Uint16(Uint16 ),
Uint32(Uint32 ),
Uint64(Uint64 ),
Uuid(Uuid ),
Custom(CustomValue ),
}Expand description A generic wrapper enum to hold any DBMS value.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Attempts to extract a reference to the inner value if it matches the variant.
Returns the type name of the value as a string.
Returns reference to the inner [CustomValue] if this is a Custom variant.
Attempts to decode a Custom variant into a concrete CustomDataType .
Returns None if this is not a Custom variant, the type tag doesn’t
match, or decoding fails.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Deserialize this value from the given Serde deserializer.
Read more Source  Encodes a Value as [discriminant: u8] + [inner_type.encode()].
For Null, only the discriminant byte is written.
For Custom, the encoding is [discriminant] + [tag_len: u16 LE] + [tag_bytes] + [data_len: u16 LE] + [encoded_bytes].
The size characteristic of the data type.
Read more The alignment requirement in bytes for the data type.
Read more Encodes the data type into a vector of bytes.
Decodes the data type from a slice of bytes.
Returns the size in bytes of the encoded data type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
The associated error which can be returned from parsing.
Parses a string
s to return a value of this type.
Read more Compares and returns the maximum of two values.
Read more Compares and returns the minimum of two values.
Read more Restrict a value to a certain interval.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more Tests less than (for
self and
other) and is used by the
< operator.
Read more Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more Tests greater than (for
self and
other) and is used by the
>
operator.
Read more Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more Serialize this value into the given Serde serializer.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.