Module memory

Module memory 

Enums

DataSize
Represents the size of data types used in the DBMS.
DecodeError
An enum representing possible decoding errors.
MemoryError
An enum representing possible memory-related errors.

Constants

DEFAULT_ALIGNMENT
Default alignment in bytes for DataSize::Dynamic data types.

Traits

Encode
This trait defines the encoding and decoding behaviour for data types used in the DBMS.

Type Aliases

MSize
Size type for memory operations.
MemoryResult
The result type for memory operations.
Page
Type identifying a memory page number.
PageOffset
Type identifying an offset within a memory page.