Module utils

Module utils 

Functions

self_reference_values
Helper function which takes a list of (ValuesSource, Value) tuples, takes only those with ValuesSource::Foreign matching the provided table and column names, and returns a vector of the corresponding Values with the ValuesSource set to ValuesSource::This.