This module exposes all the types related to queries that can be performed on the DBMS.
Structs
- Join
- A JOIN clause specifying which table to join and on which columns.
- Query
- A struct representing a query in the DBMS.
- Query
Builder - A builder for constructing database
Queryes.
Enums
- Delete
Behavior - Defines the behavior for delete operations regarding foreign key constraints.
- Filter
super::Queryfilters.- Join
Type - Specifies the JOIN operation type.
- JsonCmp
- Represents comparison operations for JSON values.
- Json
Filter - JSON-specific filter operations.
- Order
Direction - An enum representing the direction of ordering in a query.
- Query
Error - An enum representing possible errors that can occur during query operations.
- Select
- An enum representing the fields to select in a query.
Type Aliases
- Query
Result - The result type for query operations.