pub struct Query {
pub eager_relations: Vec<String>,
pub joins: Vec<Join>,
pub filter: Option<Filter>,
pub order_by: Vec<(String, OrderDirection)>,
pub limit: Option<usize>,
pub offset: Option<usize>,
/* private fields */
}Expand description
A struct representing a query in the DBMS.
Fields
eager_relations: Vec<String>Relations to eagerly load with the main records.
joins: Vec<Join>Join operations
filter: Option<Filter>Filter to apply to the query.
order_by: Vec<(String, OrderDirection)>Order by clauses for sorting the results.
limit: Option<usize>Limit on the number of records to return.
offset: Option<usize>Offset for pagination.
Implementations
Sourceimpl Query
impl Query
Sourcepub fn builder() -> QueryBuilder
pub fn builder() -> QueryBuilder
Creates a new QueryBuilder for building a query.
Sourcepub fn all_selected(&self) -> bool
pub fn all_selected(&self) -> bool
Returns whether all columns are selected in the query.
Sourcepub fn columns<T>(&self) -> Vec<String>where
T: TableSchema,
pub fn columns<T>(&self) -> Vec<String>where
T: TableSchema,
Returns the list of columns to be selected in the query.
Sourcepub fn raw_columns(&self) -> &[String]
pub fn raw_columns(&self) -> &[String]
Returns the raw column names from the Select clause.
Unlike columns::<T>(), this does not expand Select::All
using the table schema.