pub struct QueryBuilder { /* private fields */ }Expand description
A builder for constructing database Queryes.
Implementations
Sourceimpl QueryBuilder
impl QueryBuilder
Sourcepub fn build(self) -> Query
pub fn build(self) -> Query
Builds and returns a Query object based on the current state of the QueryBuilder.
Sourcepub fn fields<I>(self, fields: I) -> Selfwhere
I: IntoIterator<Item = &'static str>,
pub fn fields<I>(self, fields: I) -> Selfwhere
I: IntoIterator<Item = &'static str>,
Adds multiple fields to select in the query.
Sourcepub fn with(self, table_relation: &str) -> Self
pub fn with(self, table_relation: &str) -> Self
Adds a relation to eagerly load with the main records.
Sourcepub fn inner_join(self, table: &str, left_col: &str, right_col: &str) -> Self
pub fn inner_join(self, table: &str, left_col: &str, right_col: &str) -> Self
Adds an INNER JOIN operation to this query
Sourcepub fn left_join(self, table: &str, left_col: &str, right_col: &str) -> Self
pub fn left_join(self, table: &str, left_col: &str, right_col: &str) -> Self
Adds a LEFT JOIN operation to this query
Sourcepub fn right_join(self, table: &str, left_col: &str, right_col: &str) -> Self
pub fn right_join(self, table: &str, left_col: &str, right_col: &str) -> Self
Adds a RIGHT JOIN operation to this query
Sourcepub fn full_join(self, table: &str, left_col: &str, right_col: &str) -> Self
pub fn full_join(self, table: &str, left_col: &str, right_col: &str) -> Self
Adds a FULL JOIN operation to this query
Sourcepub fn order_by_asc(self, field: &str) -> Self
pub fn order_by_asc(self, field: &str) -> Self
Adds an ascending order by clause for the specified field.
Sourcepub fn order_by_desc(self, field: &str) -> Self
pub fn order_by_desc(self, field: &str) -> Self
Adds a descending order by clause for the specified field.
Sourcepub fn filter(self, filter: Option<Filter>) -> Self
pub fn filter(self, filter: Option<Filter>) -> Self
Sets a filter for the query, replacing any existing filter.