Module table

Module table 

This module contains types related to database tables.

Structs

CandidColumnDef
Serializable column definition for API boundaries.
CandidForeignKeyDef
Serializable foreign key definition for API boundaries.
ColumnDef
Defines a column in a database table.
ForeignKeyDef
Defines a foreign key relationship for a column.

Enums

CandidDataTypeKind
Serializable data type kind for API boundaries.
TableError
Table related errors
ValuesSource
Indicates the source of the column values.

Traits

InsertRecord
This trait represents a record for inserting into a table.
TableRecord
This trait represents a record returned by a crate::dbms::query::Query for a table.
TableSchema
Table schema representation.
UpdateRecord
This trait represents a record for updating a table.

Functions

flatten_table_columns
Flattens TableColumns rows into flat column-value pairs.

Type Aliases

TableColumns
TableFingerprint
A type representing a unique fingerprint for a table schema.