This module contains types related to database tables.
Structs
- Candid
Column Def - Serializable column definition for API boundaries.
- Candid
Foreign KeyDef - Serializable foreign key definition for API boundaries.
- Column
Def - Defines a column in a database table.
- Foreign
KeyDef - Defines a foreign key relationship for a column.
Enums
- Candid
Data Type Kind - Serializable data type kind for API boundaries.
- Table
Error - Table related errors
- Values
Source - Indicates the source of the column values.
Traits
- Insert
Record - This trait represents a record for inserting into a table.
- Table
Record - This trait represents a record returned by a
crate::dbms::query::Queryfor a table. - Table
Schema - Table schema representation.
- Update
Record - This trait represents a record for updating a table.
Functions
- flatten_
table_ columns - Flattens
TableColumnsrows into flat column-value pairs.
Type Aliases
- Table
Columns - Table
Fingerprint - A type representing a unique fingerprint for a table schema.