pub struct IndexDef(pub &'static [&'static str]);Expand description
Defines an index on one or more columns of a table.
Contains a static slice of column names that make up the index, in the order they are defined.
Tuple Fields
0: &'static [&'static str]Implementations